==> imageio-ext-gdalidrisi-1.4-20250317.132734-44-sources.jar: it/geosolutions/imageio/plugins/idrisi/IDRISIImageReader.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2009, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.idrisi;

import it.geosolutions.imageio.gdalframework.GDALImageReader;

import java.awt.image.RenderedImage;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * {@link IDRISIImageReader} is a {@link GDALImageReader} able to create
 * {@link RenderedImage} from ASCII arcGrid files.
 * 
 * @author Simone Giannecchini, GeoSolutions.
 * @author Daniele Romagnoli, GeoSolutions.
 * 
 */
public class IDRISIImageReader extends GDALImageReader {

	private static final Logger LOGGER = Logger
			.getLogger(IDRISIImageReader.class.toString());

	public IDRISIImageReader(IDRISIImageReaderSpi originatingProvider) {
		super(originatingProvider,0);
		if (LOGGER.isLoggable(Level.FINE))
			LOGGER.fine("IDRISIImageReader Constructor");
	}

}

==> imageio-ext-gdalidrisi-2.0.1-sources.jar: it/geosolutions/imageio/plugins/idrisi/IDRISIImageReader.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2009, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.idrisi;

import it.geosolutions.imageio.gdalframework.GDALImageReader;
import java.awt.image.RenderedImage;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * {@link IDRISIImageReader} is a {@link GDALImageReader} able to create {@link RenderedImage} from ASCII arcGrid files.
 *
 * @author Simone Giannecchini, GeoSolutions.
 * @author Daniele Romagnoli, GeoSolutions.
 */
public class IDRISIImageReader extends GDALImageReader {

    private static final Logger LOGGER = Logger.getLogger(IDRISIImageReader.class.toString());

    public IDRISIImageReader(IDRISIImageReaderSpi originatingProvider) {
        super(originatingProvider, 0);
        if (LOGGER.isLoggable(Level.FINE)) LOGGER.fine("IDRISIImageReader Constructor");
    }
}
